@@ -19,10 +19,10 @@ package stats
 
 import (
 	"fmt"
+	"strconv"
 	"strings"
 	"time"
 
-	"github.com/elastic/beats/libbeat/common/cfgwarn"
 	"github.com/elastic/beats/metricbeat/helper"
 	"github.com/elastic/beats/metricbeat/helper/elastic"
 	"github.com/elastic/beats/metricbeat/mb"
@@ -39,8 +39,9 @@ func init() {
 }
 
 const (
-	statsPath    = "api/stats"
-	settingsPath = "api/settings"
+	statsPath             = "api/stats"
+	settingsPath          = "api/settings"
+	usageCollectionPeriod = 24 * time.Hour
 )
 
 var (
@@ -54,14 +55,14 @@ var (
 // MetricSet type defines all fields of the MetricSet
 type MetricSet struct {
 	*kibana.MetricSet
-	statsHTTP    *helper.HTTP
-	settingsHTTP *helper.HTTP
+	statsHTTP            *helper.HTTP
+	settingsHTTP         *helper.HTTP
+	usageLastCollectedOn time.Time
+	isUsageExcludable    bool
 }
 
 // New create a new instance of the MetricSet
 func New(base mb.BaseMetricSet) (mb.MetricSet, error) {
-	cfgwarn.Experimental("The " + base.FullyQualifiedName() + " metricset is experimental")
-
 	ms, err := kibana.NewMetricSet(base)
 	if err != nil {
 		return nil, err
@@ -77,7 +78,7 @@ func New(base mb.BaseMetricSet) (mb.MetricSet, error) {
 		return nil, err
 	}
 
-	isStatsAPIAvailable, err := kibana.IsStatsAPIAvailable(kibanaVersion)
+	isStatsAPIAvailable := kibana.IsStatsAPIAvailable(kibanaVersion)
 	if err != nil {
 		return nil, err
 	}
@@ -88,17 +89,13 @@ func New(base mb.BaseMetricSet) (mb.MetricSet, error) {
 	}
 
 	if ms.XPackEnabled {
-		cfgwarn.Experimental("The experimental xpack.enabled flag in the " + ms.FullyQualifiedName() + " metricset is enabled.")
-
 		// Use legacy API response so we can passthru usage as-is
 		statsHTTP.SetURI(statsHTTP.GetURI() + "&legacy=true")
 	}
 
 	var settingsHTTP *helper.HTTP
 	if ms.XPackEnabled {
-		cfgwarn.Experimental("The experimental xpack.enabled flag in the " + ms.FullyQualifiedName() + " metricset is enabled.")
-
-		isSettingsAPIAvailable, err := kibana.IsSettingsAPIAvailable(kibanaVersion)
+		isSettingsAPIAvailable := kibana.IsSettingsAPIAvailable(kibanaVersion)
 		if err != nil {
 			return nil, err
 		}
@@ -123,6 +120,8 @@ func New(base mb.BaseMetricSet) (mb.MetricSet, error) {
 		ms,
 		statsHTTP,
 		settingsHTTP,
+		time.Time{},
+		kibana.IsUsageExcludable(kibanaVersion),
 	}, nil
 }
 
@@ -139,6 +138,18 @@ func (m *MetricSet) Fetch(r mb.ReporterV2) {
 }
 
 func (m *MetricSet) fetchStats(r mb.ReporterV2, now time.Time) {
+	// Collect usage stats only once every usageCollectionPeriod
+	if m.isUsageExcludable {
+		origURI := m.statsHTTP.GetURI()
+		defer m.statsHTTP.SetURI(origURI)
+
+		shouldCollectUsage := m.shouldCollectUsage(now)
+		if shouldCollectUsage {
+			m.usageLastCollectedOn = now
+		}
+		m.statsHTTP.SetURI(origURI + "&exclude_usage=" + strconv.FormatBool(!shouldCollectUsage))
+	}
+
 	content, err := m.statsHTTP.FetchContent()
 	if err != nil {
 		elastic.ReportAndLogError(err, r, m.Log)
@@ -179,3 +190,7 @@ func (m *MetricSet) fetchSettings(r mb.ReporterV2, now time.Time) {
 func (m *MetricSet) calculateIntervalMs() int64 {
 	return m.Module().Config().Period.Nanoseconds() / 1000 / 1000
 }
+
+func (m *MetricSet) shouldCollectUsage(now time.Time) bool {
+	return now.Sub(m.usageLastCollectedOn) > usageCollectionPeriod
+}
